==> downloads.html?file=gigkalender_v1.2.61_069.zip: gigkalender/calendar/includes/addGig/GigFlyer.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<tr>
          <td>'.$L_GigFlyer.':</td>
          <td>';
  // Dateinamen in Array schreiben
    $directory = 'flyer/';
    $handle=opendir ($directory);
    $files = array();
    while ($file = readdir ($handle))
    if ($file != "." && $file != "..") { $files[] = $file; }
    // sort ( $files );
    $Dateiendungen = array( '.jpg', '.jpeg', '.gif', '.png' );
    $FlyerFile = false;
    for ( $i=0; $i<count($Dateiendungen); $i++)
    {
      if ( in_array ( $GigID.$Dateiendungen[$i], $files ) ) $FlyerFile = 'flyer/'.$GigID.$Dateiendungen[$i];
    }
    if ( $FlyerFile )
    {
      // $ImageInfos = getimagesize  ( $FlyerFile );
      // $ImageWidth = $ImageInfos[0];
      // $ImageHeight = $ImageInfos[1];
      // $WidthToHeightRatio = $ImageWidth/$ImageHeight;
      // echo $ImageWidth.' x '.$ImageHeight.' ('.$WidthToHeightRatio.')';
      
      // Bilddaten feststellen
  $size=getimagesize($FlyerFile);
  $breite=$size[0];
  $hoehe=$size[1];

  //hier die Breite festlegen
    // $neueBreite=200;
    // $neueHoehe=intval($hoehe*$neueBreite/$breite);
    $neueHoehe=100;
    $neueBreite=intval($neueHoehe*$breite/$hoehe);

  if($size[2]==1) {
  // GIF
  $altesBild=ImageCreateFromGIF($FlyerFile);
  $neuesBild=ImageCreate($neueBreite,$neueHoehe);
  ImageCopyResized($neuesBild,$altesBild,0,0,0,0,$neueBreite,$neueHoehe,$breite,$hoehe);
  ImageGIF($neuesBild);
  }

  elseif($size[2]==2) {
  // JPG
  $altesBild=ImageCreateFromJPEG($FlyerFile);
  $neuesBild=imagecreatetruecolor($neueBreite,$neueHoehe);
  // echo $neuesBild.'x<br /><br /><br />';
  ImageCopyResized($neuesBild,$altesBild,0,0,0,0,$neueBreite,$neueHoehe,$breite,$hoehe);
  imagejpeg($neuesBild, $directory.$GigID.'_thumb.jpg', 80);
  }

  elseif($size[2]==3) {
  // PNG
  $altesBild=ImageCreateFromPNG($FlyerFile);
  $neuesBild=imagecreatetruecolor($neueBreite,$neueHoehe);
  ImageCopyResized($neuesBild,$altesBild,0,0,0,0,$neueBreite,$neueHoehe,$breite,$hoehe);
  ImagePNG($neuesBild);
  }
  echo '<img src="'.$directory.$GigID.'_thumb.jpg"  alt="Flyer '.$FlyerFile.'" title="Flyer '.$FlyerFile.'" /><br />';
    }
    else
    {
      echo '<form action="input_file.htm" method="post" enctype="multipart/form-data">
      <fieldset>
    <input name="Datei" type="file" size="50" maxlength="100000" accept="image/*" />
    </fieldset>
</form>';
    }
  echo '</td>
        <td></td>
      </tr>';
?>

==> downloads.html?file=gigkalender_v1.2.80_171.zip: gigkalender/calendar/includes/addGig/GigFlyer.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<tr>
          <td>'.$L_GigFlyer.':</td>
          <td>';
  // Dateinamen in Array schreiben
    $directory = 'flyer/';
    $handle=opendir ($directory);
    $files = array();
    while ($file = readdir ($handle))
    if ($file != "." && $file != "..") { $files[] = $file; }
    // sort ( $files );
    $Dateiendungen = array( '.jpg', '.jpeg', '.gif', '.png' );
    $FlyerFile = false;
    for ( $i=0; $i<count($Dateiendungen); $i++)
    {
      if ( in_array ( $GigID.$Dateiendungen[$i], $files ) ) $FlyerFile = 'flyer/'.$GigID.$Dateiendungen[$i];
    }
    if ( $FlyerFile )
    {
      // $ImageInfos = getimagesize  ( $FlyerFile );
      // $ImageWidth = $ImageInfos[0];
      // $ImageHeight = $ImageInfos[1];
      // $WidthToHeightRatio = $ImageWidth/$ImageHeight;
      // echo $ImageWidth.' x '.$ImageHeight.' ('.$WidthToHeightRatio.')';
      
      // Bilddaten feststellen
  $size=getimagesize($FlyerFile);
  $breite=$size[0];
  $hoehe=$size[1];

  //hier die Breite festlegen
    // $neueBreite=200;
    // $neueHoehe=intval($hoehe*$neueBreite/$breite);
    $neueHoehe=100;
    $neueBreite=intval($neueHoehe*$breite/$hoehe);

  if($size[2]==1) {
  // GIF
  $altesBild=ImageCreateFromGIF($FlyerFile);
  $neuesBild=ImageCreate($neueBreite,$neueHoehe);
  ImageCopyResized($neuesBild,$altesBild,0,0,0,0,$neueBreite,$neueHoehe,$breite,$hoehe);
  ImageGIF($neuesBild);
  }

  elseif($size[2]==2) {
  // JPG
  $altesBild=ImageCreateFromJPEG($FlyerFile);
  $neuesBild=imagecreatetruecolor($neueBreite,$neueHoehe);
  // echo $neuesBild.'x<br /><br /><br />';
  ImageCopyResized($neuesBild,$altesBild,0,0,0,0,$neueBreite,$neueHoehe,$breite,$hoehe);
  imagejpeg($neuesBild, $directory.$GigID.'_thumb.jpg', 80);
  }

  elseif($size[2]==3) {
  // PNG
  $altesBild=ImageCreateFromPNG($FlyerFile);
  $neuesBild=imagecreatetruecolor($neueBreite,$neueHoehe);
  ImageCopyResized($neuesBild,$altesBild,0,0,0,0,$neueBreite,$neueHoehe,$breite,$hoehe);
  ImagePNG($neuesBild);
  }
  echo '<img src="'.$directory.$GigID.'_thumb.jpg"  alt="Flyer '.$FlyerFile.'" title="Flyer '.$FlyerFile.'" /><br />';
    }
    else
    {
      echo '<form action="input_file.htm" method="post" enctype="multipart/form-data" accept-charset="UTF-8">
      <fieldset>
    <input name="Datei" type="file" size="50" maxlength="100000" accept="image/*" />
    </fieldset>
</form>';
    }
  echo '</td>
        <td></td>
      </tr>';
?>
